<?php
/**
 * @file example.php
 * @copyright Sebastian Beyl, Zentrum fuer LehrerInnenbildung, Universitaet zu Koeln, 2020
 * @version 20201009
 */


// Optional step: If you want to set another url to use the PAUKR system, you
// can set the url using this define. It can be useful if you have to pipe it
// through ssh or proxy. If the define is not set, it will be set automatically.
define('PAUKR_SERVER_URL', 'paukr.zfl.uni-koeln.de');


// Include the PAUKR client class. You can store the class inside any directory,
// there is no dependency to any other class. Only curl for php has to be activated,
// but this is done in most web server szenarios.
require_once 'class.paukr.php';


// Create a new PAUKR object. While creating it, it is a good idea to give your API key
// as the first parameter. Optional, you can use the setToken method.
$o_Paukr = new Paukr('yourAPIKeyHere');
// optional: $o_Paukr->setToken('yourAPIKeyHere');


// Now your object is ready to read papers from a valid matrikel no. very easily. This two line
// example returns an array of all available papers connected to one matrikel no.
$arr_PapersAvailable = $o_Paukr->getPapers('1234567');
print_r($arr_PapersAvailable);


// If you want to show a specific paper, you can stream it directly to the browser. Please note that
// you have to start with this output BEFORE you set any other output! If you decide to show it to the browser,
// first set the header to show a pdf, alternative you can set the header to download the file.
header("Content-type:application/pdf");
// alternative for download: header("Content-Disposition:attachment;filename=downloaded.pdf");
$s_FileContent = $o_Paukr->getPaperFile('1234567', '20200101_MA_Abschlussarbeit.pdf');
print $s_FileContent;


// If you want to write a new file to the PAUKR system, first read a file to the memory. This can be
// done by using file_get_contents, but you can use any other method. Push this stream now to the PAUKR
// system by using the writePaperFile method using its valid parameters. You can look up valid paramters
// inside the PAUKR documentation or inside the method inline documentation.
$file = file_get_contents('example_file.pdf');
$b_Success = $o_Paukr->writePaperFile(
    $file,
    '1234567',
    '20200101',
    'MA',
    'Abschlussarbeit',
    'pdf');
if ($b_Success) { print 'successful uploaded!'; } else { print 'an error has happened!'; }
